@@ -181,6 +181,13 @@ impl Tensor {
             v: Rc::new(RefCell::new(self.v.borrow().get_patch(range, step)))
         }
     }
+    pub fn set_patch(&self, other: &Tensor,
+                     range: &[(usize, usize)], step: Option<&[usize]>) -> Tensor {
+        Tensor {
+            v: Rc::new(RefCell::new(self.v.borrow().set_patch(
+                &other.v.borrow(), range, step)))
+        }
+    }
 
     pub fn same_shape(&self, o: &Tensor) -> bool {
         let a = self.size();
@@ -293,6 +300,10 @@ impl Tensor {
             v: Rc::new(RefCell::new(TypedTensor::ones_f32(dim))),
         }
     }
+    pub fn twos(dim: &[usize]) -> Tensor {
+        let a = Self::ones(dim);
+        a.add(&a)
+    }
     // ones_like
     tensor_method_single_tensor_return!(ones_like);
     // range
@@ -643,6 +654,7 @@ impl Tensor {
     tensor_method_3_option_tensor_return!(svd);
     tensor_method_1_option_tensor_return!(inv);
     tensor_method_single_tensor_return!(pinv);
+    tensor_method_single_tensor_return!(tr);
 
 
     // Comparison Ops
@@ -797,7 +809,7 @@ mod tests {
     fn normalize() {
         let a = Tensor::from_vec_f32(&vec![1., 2., 3., 4., 5., 6., ], &vec![3, 2]);
         let b = a.normalize_unit();
-        assert_eq!(b, Tensor::from_vec_f32(&vec![-1.2247448, -1.2247448, 0.,0., 1.2247448, 1.2247448], &vec![3, 2]));
+        assert_eq!(b, Tensor::from_vec_f32(&vec![0.10482848, 0.20965695, 0.31448543, 0.4193139, 0.5241424, 0.62897086,], &vec![3, 2]));
     }
 
     // test for basic ops
