@@ -19,8 +19,8 @@ impl<T> IndexSlicing for GenTensor<T> where T: num_traits::Float {
             }
         }
 
-        let mut cap = 1;
-        let mut new_dim = Vec::new();
+        let mut cap = 1; // total number of elements of the output
+        let mut new_dim = Vec::new(); // size of the output
         let mut outer_size = 1;
         let mut inner_size = 1;
         for (i, item) in total_dim.iter().enumerate() {
@@ -259,14 +259,18 @@ impl<T> IndexSlicing for GenTensor<T> where T: num_traits::Float {
 
     fn squeeze(&self, dim: Option<usize>) -> Self {
         let mut new_shape = Vec::new();
-        for i in 0..new_shape.len() {
-            if (new_shape[i] == 1 && dim.is_some() && i == dim.unwrap()) ||
-                (new_shape[i] == 1 && dim.is_none()) {
+        let size = self.size();
+        for i in 0..size.len() {
+            if (size[i] == 1 && dim.is_some() && i == dim.unwrap()) ||
+                (size[i] == 1 && dim.is_none()) {
                 continue
             } else {
-                new_shape.push(new_shape[i]);
+                new_shape.push(size[i]);
             }
         }
+        if new_shape.len() == 0 {
+            new_shape.push(1);
+        }
         GenTensor::new_raw(self.get_data(), &new_shape)
     }
 
@@ -543,4 +547,11 @@ mod tests {
         println!("{:?}", b);
         assert_eq!(b, GenTensor::<f32>::new_raw(&[1., 2., 3., 1., 2., 3., 1., 2., 3., 1., 2., 3., 1., 2., 3., 1., 2., 3., 1., 2., 3., 1., 2., 3. ], &[4, 6]));
     }
+
+    #[test]
+    fn squeeze() {
+        let a = GenTensor::<f64>::new_raw(&[1., 2., 3.], &[3, 1]);
+        let b = a.squeeze(None);
+        println!("{:?}", b);
+    }
 }
