@@ -739,6 +739,23 @@ impl<T> GenTensor<T> where T: num_traits::Float {
         }
         ret
     }
+
+    pub fn log10_like(&self) -> GenTensor<T> {
+	let new_data = vec![T::from(2.302585092994046).unwrap(); self.d.len()];
+        let new_dim = self.dim.to_vec();
+        GenTensor {
+            d: new_data,
+            dim: new_dim,
+        }
+    }
+    pub fn log2_like(&self) -> GenTensor<T> {
+	let new_data = vec![T::from(0.6931471805599453).unwrap(); self.d.len()];
+        let new_dim = self.dim.to_vec();
+        GenTensor {
+            d: new_data,
+            dim: new_dim,
+        }
+    }
     
     /// element-wise add with right-hand broadcast.
     ///
@@ -826,7 +843,7 @@ impl<T> GenTensor<T> where T: num_traits::Float {
             panic!("matmul expect matched size {:?}, {:?}", self.dim, o.dim);
         }
         if self.size().len() == 1 && o.size().len() == 1 {
-            panic!("Two vector have not matched size for matmul!");
+            panic!("Two vector have not matched size for matmul! {:?}, {:?}", self.numel(), o.numel());
         }
         let inner = o.dim[0];
         let mut cap = 1;
